/*
#############
DEFAULT THEME
#############
*/

.grid-container {
    background-color: #c2e2fc;
}

.grid-container>div {
    background-color: rgba(255, 255, 255, 0.8);
}

.education-dates,
.experience-dates {
    font-style: italic;
}
